pub struct Box<T> { /* private fields */ }
A pointer type for dynamically allocated memory.

For more details see module-level documentation

Implementations

Try to move a value to an allocated memory space.

Create a box from a NonNull pointer

Returns the pointer to the box structure on memory.