Module bern_kernel::mem::linked_list[][src]

Doubly-linked list.

The goal here is to create a fast and efficient linked list. Lists use an array of nodes as memory pool, the array must be static.

In contrast to std::collections::LinkedList you will only ever get a reference to a node and never a copy/move.

Structs

Cursor

A cursor over a LinkedList with editing operations.

Iter

An iterator over the elements of a LinkedList.

IterMut

An mutable iterator over the elements of a LinkedList.

LinkedList

A doubly-linked list owning its nodes.

Node

An element/node of a list.