Trait bern_kernel::mem::queue::SyncConsumer
source · [−]pub unsafe trait SyncConsumer { }Expand description
Implement this trait if the consumer channel is thread safe.
pub unsafe trait SyncConsumer { }Implement this trait if the consumer channel is thread safe.