Trait bern_kernel::mem::queue::SyncProducer
source · [−]pub unsafe trait SyncProducer { }Expand description
Implement this trait if the producer channel is thread safe.
pub unsafe trait SyncProducer { }Implement this trait if the producer channel is thread safe.