Function bern_kernel::syscall::yield_now
source · [−]pub fn yield_now()Expand description
Yield the CPU.
Note: If the calling task is the only ready task of its priority it will be put to running state again.
pub fn yield_now()Yield the CPU.
Note: If the calling task is the only ready task of its priority it will be put to running state again.